function [fr,vm,vmins,vmaxs,v]=three_tube_model_pt2(rG,rL,l1,l2,l3,A1,A2,A3)

% inputs:  
%   rG=glottal impedance 
%   rL=lip impedance
%   l1=length of section 1
%   l2=length of section 2
%   l3=length of section 3
%   A1=area of section 1 
%   A2=area of section 2
%   A3=area of section 3
%
% outputs:
%   fr: frequency scale from 0 to 5000 Hz in steps of 1 Hz
%   vm: log magnitude frequency response in steps of 1 Hz
%   vmins: minimum of log magnitude frequency response
%   vmaxs: maximum of log magnitude frequency response
%   v: three tube vocal tract complex frequency response, f=(0:5000)

% computed terms of frequency response
%   num(f)=0.5 (1+rG)(1+rL)(1+r1) exp(-j 2*pi f (tau1+tau2))
%   den1(f)=r1*rG exp(-j 2*pi f 2 tau1)
%   den2(f)=r1*rL exp(-j 2*pi f 2 tau2)
%   den3(f)=rG*rL exp(-j 2*pi f 2 (tau1+tau2))
%   den(f)=1+den1+den2+den3

% c: speed of sound in cm/sec (approximate as 35,000 rather than 34,029
        c=35000; 

% compute reflection coefficient for 3-tube model
        l=l1+l2+l3;
        r1=(A2-A1)/(A2+A1);
        r2=(A3-A2)/(A3+A2);
        tau1=l1/c;
        tau2=l2/c;
        tau3=l3/c;
        
% compute numerator component and denominator components
        numc=0.5*(1+rG)*(1+rL)*(1+r1)*(1+r2);
        denc1=rG*r1;
        denc2=rG*r2;
        denc3=rG*rL;
        denc4=r1*r2;
        denc5=r1*rL;
        denc6=r2*rL;
        denc7=rG*r1*r2*rL;
        
% calculate log magnitude frequency response, vm       
        freq=0:1:5000;
        num=complex(numc*cos(2*pi*freq*l/c),...
            -numc*sin(2*pi*freq*l/c));
        den=complex(1+denc1*cos(2*pi*freq*2*l1/c)+...
            denc2*cos(2*pi*freq*2*(l1+l2)/c)...
            +denc3*cos(2*pi*freq*2*l/c)+denc4*cos(2*pi*freq*2*l2/c)+...
            denc5*cos(2*pi*freq*2*(l2+l3)/c)...
            +denc6*cos(2*pi*freq*2*l3/c)+denc7*cos(2*pi*freq*2*(l1+l3)/c),...
            -denc1*sin(2*pi*freq*2*l1/c)-denc2*sin(2*pi*freq*2*(l1+l2)/c)...
            -denc3*sin(2*pi*freq*2*l/c)-denc4*sin(2*pi*freq*2*l2/c)-...
            denc5*sin(2*pi*freq*2*(l2+l3)/c)...
            -denc6*sin(2*pi*freq*2*l3/c)-denc7*sin(2*pi*freq*2*(l1+l3)/c));
        v=num./den;
        vm=20*log10(abs(v));
        
% find maximum and minimum log magnitude responses
        vmaxs=-1000;
        vmins=1000;
        vmaxs=max(vmaxs,max(vm));
        vmins=min(vmins,min(vm));
        fr=freq;
end